@@ -233,6 +233,11 @@ def erfcx_inplace(a):
     """scaled complementary error function"""
 
 
+@scalar_elemwise
+def owens_t_inplace(h, a):
+    """owens t function"""
+
+
 @scalar_elemwise
 def gamma_inplace(a):
     """gamma function"""
@@ -318,13 +323,23 @@ def softplus_inplace(x):
     """Compute log(1 + exp(x)), also known as softplus or log1pexp"""
 
 
+@scalar_elemwise
+def log1mexp_inplace(x):
+    """Compute log(1 - exp(x)), also known as log1mexp"""
+
+
+@scalar_elemwise
+def betainc_inplace(a, b, x):
+    """Regularized incomplete beta function"""
+
+
 @scalar_elemwise
 def second_inplace(a):
     """Fill `a` with `b`"""
 
 
 fill_inplace = second_inplace
-pprint.assign(fill_inplace, printing.FunctionPrinter("fill="))
+pprint.assign(fill_inplace, printing.FunctionPrinter(["fill="]))
 
 
 @scalar_elemwise(symbolname="scalar_maximum_inplace")
@@ -389,4 +404,4 @@ pprint.assign(pow_inplace, printing.OperatorPrinter("**=", 1, "right"))
 def transpose_inplace(x, **kwargs):
     "Perform a transpose on a tensor without copying the underlying storage"
     dims = list(range(x.ndim - 1, -1, -1))
-    return DimShuffle(x.broadcastable, dims, inplace=True)(x)
+    return DimShuffle(x.broadcastable, dims)(x)
