@@ -1,5 +1,6 @@
 import builtins
 import warnings
+from typing import TYPE_CHECKING, Optional
 
 import numpy as np
 
@@ -34,6 +35,7 @@ from aesara.tensor.elemwise import (
 from aesara.tensor.shape import shape, specify_broadcastable
 from aesara.tensor.type import (
     DenseTensorType,
+    TensorType,
     complex_dtypes,
     continuous_dtypes,
     discrete_dtypes,
@@ -47,6 +49,9 @@ from aesara.tensor.utils import as_list
 from aesara.tensor.var import TensorConstant, _tensor_py_operators
 
 
+if TYPE_CHECKING:
+    from numpy.typing import ArrayLike, DTypeLike
+
 # We capture the builtins that we are going to replace to follow the numpy API
 _abs = builtins.abs
 
@@ -1043,10 +1048,6 @@ def abs(a):
     """|`a`|"""
 
 
-# These are deprecated and will be removed
-abs_ = abs
-
-
 pprint.assign(abs, printing.PatternPrinter(("|%(0)s|", -1000)))
 
 
@@ -1075,10 +1076,6 @@ def reciprocal(a):
     """1.0/a"""
 
 
-# This is deprecated and will be removed
-inv = reciprocal
-
-
 @scalar_elemwise
 def log(a):
     """base e logarithm of a"""
@@ -1334,6 +1331,11 @@ def erfcinv(a):
     """inverse complementary error function"""
 
 
+@scalar_elemwise
+def owens_t(h, a):
+    """owens t function"""
+
+
 @scalar_elemwise
 def gamma(a):
     """gamma function"""
@@ -2851,9 +2853,145 @@ def logsumexp(x, axis=None, keepdims=False):
     return log(sum(exp(x), axis=axis, keepdims=keepdims))
 
 
+class MatMul(Op):
+    __props__ = ("dtype",)
+
+    def __init__(self, dtype=None):
+        self.dtype = dtype
+
+    @classmethod
+    def _get_output_shape(cls, x1, x2, shapes, validate=False):
+        x1_shape, x2_shape = shapes
+
+        if x1.ndim == 1 and x2.ndim == 1:
+            if validate and x1_shape[0] != x2_shape[0]:
+                raise ValueError("1d inputs must have the same length.")
+            return ()
+        elif x1.ndim == 1 and x2.ndim > 1:
+            if validate and x1_shape[0] != x2_shape[-2]:
+                raise ValueError(
+                    "length of input 1 must be equal the length "
+                    "of the 2nd-last dimension of input 2"
+                )
+            return x2_shape[:-2] + x2_shape[-1:]
+        elif x1.ndim > 1 and x2.ndim == 1:
+            if validate and x1_shape[-1] != x2_shape[0]:
+                raise ValueError(
+                    "length of input 2 must be equal the length "
+                    "of the last dimension of input 1"
+                )
+            return x1_shape[:-1]
+        elif x1.ndim == 2 and x2.ndim == 2:
+            if validate and x1_shape[-1] != x2_shape[0]:
+                raise ValueError(
+                    "number of columns of input 1 must be equal to "
+                    "the number of rows of input 2"
+                )
+            return x1_shape[:-1] + x2_shape[-1:]
+        elif x1.ndim > 2 and x2.ndim == 2:
+            if validate and x1_shape[-1] != x2_shape[0]:
+                raise ValueError(
+                    "number of rows of input 2 must be equal to "
+                    "the length of the last dimension of input 1"
+                )
+            return x1_shape[:-2] + x1_shape[-2:-1] + x2_shape[-1:]
+        elif x1.ndim == 2 and x2.ndim > 2:
+            if validate and x1_shape[-1] != x2_shape[-2]:
+                raise ValueError(
+                    "number of columns of input 1 must be equal "
+                    "the length of the 2nd-last dimension of input 2"
+                )
+            return x2_shape[:-2] + x1_shape[-2:-1] + x2_shape[-1:]
+        else:
+
+            if validate:
+                from aesara.tensor.random.basic import broadcast_shapes
+
+                bshape = broadcast_shapes(x1_shape[:-2], x2_shape[:-2])
+                if x1_shape[-1] != x2_shape[-2]:
+                    raise ValueError(
+                        "length of the last dimension of input 1 must be equal "
+                        "to the length of the 2nd-last dimension of input 2"
+                    )
+            else:
+                from aesara.tensor.extra_ops import broadcast_shape
+
+                bshape = broadcast_shape(
+                    x1_shape[:-2], x2_shape[:-2], arrays_are_shapes=True
+                )
+            return bshape + x1_shape[-2:-1] + x2_shape[-1:]
+
+    def make_node(self, a, b):
+        a = as_tensor_variable(a)
+        b = as_tensor_variable(b)
+
+        if 0 in {a.ndim, b.ndim}:
+            raise ValueError("inputs to `matmul` cannot be scalar.")
+
+        out_shape = self._get_output_shape(
+            a, b, (a.type.shape, b.type.shape), validate=True
+        )
+        out = TensorType(dtype=self.dtype, shape=out_shape)()
+        return Apply(self, [a, b], [out])
+
+    def perform(self, node, inputs, outputs):
+        x1, x2 = inputs
+        outputs[0][0] = np.matmul(x1, x2, dtype=self.dtype)
+
+    def infer_shape(self, fgraph, node, shapes):
+        x1, x2 = node.inputs
+        return [self._get_output_shape(x1, x2, shapes)]
+
+
+def matmul(x1: "ArrayLike", x2: "ArrayLike", dtype: Optional["DTypeLike"] = None):
+    """Compute the matrix product of two tensor variables.
+
+    Parameters
+    ----------
+    x1, x2
+        Input arrays, scalars not allowed.
+    dtype
+        The desired data-type for the array. If not given, then the type will
+        be determined as the minimum type required to hold the objects in the
+        sequence.
+
+    Returns
+    -------
+    out : ndarray
+        The matrix product of the inputs. This is a scalar only when both
+        `x1`, `x2` are 1-d vectors.
+
+    Raises
+    ------
+    ValueError
+        If the last dimension of `x1` is not the same size as the second-to-last
+        dimension of `x2`. If a scalar value is passed in.
+
+    Notes
+    -----
+    The behavior depends on the arguments in the following way.
+
+    - If both arguments are 2-D they are multiplied like conventional matrices.
+    - If either argument is N-D, N > 2, it is treated as a stack of matrices
+        residing in the last two indexes and broadcast accordingly.
+    - If the first argument is 1-D, it is promoted to a matrix by prepending a
+        1 to its dimensions. After matrix multiplication the prepended 1 is removed.
+    - If the second argument is 1-D, it is promoted to a matrix by appending a
+        1 to its dimensions. After matrix multiplication the appended 1 is removed.
+
+    `matmul` differs from `dot` in two important ways:
+
+    - Multiplication by scalars is not allowed, use `mul` instead.
+    - Stacks of matrices are broadcast together as if the matrices were elements,
+        respecting the signature ``(n, k), (k, m) -> (n, m)``:
+    """
+    return MatMul(dtype=dtype)(x1, x2)
+
+
 __all__ = [
     "max_and_argmax",
     "max",
+    "matmul",
     "argmax",
     "min",
     "argmin",
@@ -2878,13 +3016,11 @@ __all__ = [
     "invert",
     "bitwise_not",
     "abs",
-    "abs_",
     "exp",
     "exp2",
     "expm1",
     "neg",
     "reciprocal",
-    "inv",
     "log",
     "log2",
     "log10",
@@ -2921,6 +3057,7 @@ __all__ = [
     "erfcx",
     "erfinv",
     "erfcinv",
+    "owens_t",
     "gamma",
     "gammaln",
     "psi",
@@ -2980,3 +3117,28 @@ __all__ = [
     "logaddexp",
     "logsumexp",
 ]
+
+DEPRECATED_NAMES = [
+    ("abs_", "`abs_` is deprecated; use `abs` instead.", abs),
+    ("inv", "`inv` is deprecated; use `reciprocal` instead.", reciprocal),
+]
+
+
+def __getattr__(name):
+    """Intercept module-level attribute access of deprecated symbols.
+
+    Adapted from https://stackoverflow.com/a/55139609/3006474.
+
+    """
+    from warnings import warn
+
+    for old_name, msg, old_object in DEPRECATED_NAMES:
+        if name == old_name:
+            warn(msg, DeprecationWarning, stacklevel=2)
+            return old_object
+
+    raise AttributeError(f"module {__name__} has no attribute {name}")
+
+
+def __dir__():
+    return sorted(__all__ + [names[0] for names in DEPRECATED_NAMES])
